bayespy.inference.vmp.nodes.constant.Constant.add_plate_axis
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.add_plate_axis